@@ -10,7 +10,7 @@ from PyQt4.QtCore import (Qt, SIGNAL)
 import config as c
 
 # program modules 
-from ui_meals_window import Ui_MealsWindow
+from ui.ui_meals_window import Ui_MealsWindow
 
 class MealsWindow(QMainWindow, Ui_MealsWindow):
 
